===============================
Kyos
===============================


.. Image showing the PyPI version badge - links to PyPI
.. image:: https://img.shields.io/pypi/v/kyos.svg
        :target: https://pypi.python.org/pypi/kyos

.. Image showing the Travis Continuous Integration test status, commented out for now
.. .. image:: https://img.shields.io/travis/CFSAN-Biostatistics/kyos.svg
..        :target: https://travis-ci.org/CFSAN-Biostatistics/kyos



Tools for haploid variant calling with Deep Neural Networks.

Kyos was developed by the United States Food
and Drug Administration, Center for Food Safety and Applied Nutrition.

* Free software
* Documentation: https://kyos.readthedocs.io
* Source Code: https://github.com/CFSAN-Biostatistics/kyos
* PyPI Distribution: https://pypi.python.org/pypi/kyos


Features
--------

* Extract features from a BAM file
* Train and Test a neural network


Citing Kyos
--------------------------------------

To cite Kyos, please reference the Kyos GitHub repository:

    https://github.com/CFSAN-Biostatistics/kyos


License
-------

See the LICENSE file included in the Kyos distribution.

